How to cite our work
~~~~~~~~~~~~~~~~~~~~

If you use this software in your work, please consider citing the papers that
describe the method [Yeatman2012]_, the specific implementation [Kruper2021]_,
as well as the underlying modeling and tractography implementations in `DIPY
<https://dipy.org>`_ [Garyfallidis2014]_. If you use the RecoBundles method,
please also cite the original paper describing that method [Garyfallidis2018]_.

.. [Yeatman2012] Jason D Yeatman, Robert F Dougherty, Nathaniel J Myall, Brian A Wandell, Heidi M Feldman. Tract profiles of white matter properties: automating fiber-tract quantification. PloS One, 7: e49790. https://doi.org/10.1371/journal.pone.0049790

.. [Kruper2021] J. Kruper, J. D. Yeatman, A. Richie-Halford, D. Bloom, M. Grotheer, S. Caffarra, G. Kiar, I. I. Karipidis, E. Roy, B. Q. Chandio, E. Garyfallidis, and A. Rokem. Evaluating the reliability of human brain white matter tractometry. Aperture, in press, 2021. doi: https://doi.org/10.1101/2021.02.24.432740

.. [Garyfallidis2014] Garyfallidis E, Brett M, Amirbekian B, Rokem A, van der Walt S, Descoteaux M, Nimmo-Smith I and Dipy Contributors (2014) Dipy, a library for the analysis of diffusion MRI data. Front. Neuroinform. 8:8. doi: https://doi.org/10.3389/fninf.2014.00008

.. [Garyfallidis2018] Garyfallidis E, Côté MA, Rheault F, Sidhu J, Hau J, Petit L, Fortin D, Cunanne S, Descoteaux M. Recognition of white matter bundles using local and global streamline-based registration and clustering. Neuroimage. 2018 170:283-295. https://doi.org/10.1016/j.neuroimage.2017.07.015.